@@ -1,3 +1,3 @@
 # Global variables
 _HEADER = {"Content-Type": "application/json"}
-_PAYLOAD = {"stmt": None}
\ No newline at end of file
+_PAYLOAD = {}
\ No newline at end of file
